@@ -34,47 +34,50 @@ class FilterController : public QObject
     Q_OBJECT
 
 public:
-    explicit FilterController(QObject* parent = 0);
-    MetadataModel* metadataModel();
-    AttachedFiltersModel* attachedModel();
+    explicit FilterController(QObject *parent = 0);
+    MetadataModel *metadataModel();
+    AttachedFiltersModel *attachedModel();
 
-    QmlMetadata* metadataForService(Mlt::Service *service);
-    QmlFilter* currentFilter() const { return m_currentFilter.data(); }
+    QmlMetadata *metadataForService(Mlt::Service *service);
+    QmlFilter *currentFilter() const
+    {
+        return m_currentFilter.data();
+    }
 
 protected:
-    void timerEvent(QTimerEvent*);
+    void timerEvent(QTimerEvent *);
 
 signals:
-    void currentFilterChanged(QmlFilter* filter, QmlMetadata* meta, int index);
+    void currentFilterChanged(QmlFilter *filter, QmlMetadata *meta, int index);
     void statusChanged(QString);
-    void filterChanged(Mlt::Service*);
+    void filterChanged(Mlt::Service *);
 
 public slots:
     void setProducer(Mlt::Producer *producer = 0);
     void setCurrentFilter(int attachedIndex, bool isNew = false);
     void onFadeInChanged();
     void onFadeOutChanged();
-    void onServiceInChanged(int delta, Mlt::Service* service = 0);
-    void onServiceOutChanged(int delta, Mlt::Service* service = 0);
+    void onServiceInChanged(int delta, Mlt::Service *service = 0);
+    void onServiceOutChanged(int delta, Mlt::Service *service = 0);
     void removeCurrent();
     void onProducerChanged();
 
 private slots:
     void handleAttachedModelChange();
     void handleAttachedModelAboutToReset();
-    void addMetadata(QmlMetadata*);
-    void handleAttachedRowsRemoved(const QModelIndex & parent, int first, int last);
-    void handleAttachedRowsInserted(const QModelIndex & parent, int first, int last);
+    void addMetadata(QmlMetadata *);
+    void handleAttachedRowsRemoved(const QModelIndex &parent, int first, int last);
+    void handleAttachedRowsInserted(const QModelIndex &parent, int first, int last);
     void handleAttachDuplicateFailed(int index);
     void onQmlFilterChanged();
-    void onQmlFilterChanged(const QString& name);
+    void onQmlFilterChanged(const QString &name);
 
 private:
     void loadFilterMetadata();
 
     QFuture<void> m_future;
     QScopedPointer<QmlFilter> m_currentFilter;
-    Mlt::Service* m_mltService;
+    Mlt::Service *m_mltService;
     MetadataModel m_metadataModel;
     AttachedFiltersModel m_attachedModel;
     int m_currentFilterIndex;
