@@ -23,18 +23,23 @@
 namespace Ui {
 class TranscodeDialog;
 }
-class QCheckBox;
 
 class TranscodeDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit TranscodeDialog(const QString& message, bool isProgressive, QWidget *parent = nullptr);
+    explicit TranscodeDialog(const QString &message, bool isProgressive, QWidget *parent = nullptr);
     ~TranscodeDialog();
-    int format() const { return m_format; }
+    int format() const
+    {
+        return m_format;
+    }
     void showCheckBox();
-    bool isCheckBoxChecked() const { return m_isChecked; }
+    bool isCheckBoxChecked() const
+    {
+        return m_isChecked;
+    }
     bool deinterlace() const;
     bool fpsOverride() const;
     double fps() const;
